pub enum LibType {
    RustLib,
}
LibType describes what format the Flow Library is written in

Variants

RustLib

RustLib indicates that the library is written in rust with a Cargo.toml to compile it natively