load library metadata from the given url using the provider.
Currently it uses the package table of Cargo.toml as a source but it could
easily use another file as along as it has the required fields to satisfy MetaData struct
load library metadata from the given url using the provider.
Currently it uses the package table of Cargo.toml as a source but it could
easily use another file as along as it has the required fields to satisfy MetaData struct