Model defines the structures for the different data types in a flow for use in memory
Modules
connection defines the connection between one process output to another process’s input
datatype specifies the type o fdata permitted on a input, output or connection
flow is the definition of an entire flow, including children flows
function defines a function in a flow or library
io is the object used to define a process’s inputs or outputs
name is used to name various objects in the flow model
process is a generic definition of a function or a flow so a flow refering to it or using
it does not need to know or define how it is implemented
process_reference is an object used within a flow to reference a process defined elsewhere
route defines a location in the hierarchy of a flow and can locate a flow, a function, or one of
its inputs or outputs