pub enum Direction {
FROM,
TO,
}
Direction defines whether a Connection is coming from an IO or to an IO
The Connection is FROM this IO to another
The Connection is TO this IO from another
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.