pub struct Connection { /* private fields */ }
Connection defines a connection between the output of one function or flow to the input of another function or flow and maybe optionally named for legibility/debugging.

Implementations

Return the name

Connect the from_io to the to_io if they are compatible

Return a reference to the from_io

Return a mutable reference to the from_io

Return a reference to the to_io

Return a mutable reference to the to_io

Get at what level in the flow hierarchy this connection exists (source)