pub trait HasDataTypes {
    fn datatypes(&self) -> &Vec<DataType>;
}
Trait that is used on multiple objects to get their data type

Required methods

Return a reference to the datatype of the object implementing this trait

Implementors