pub struct Function { /* private fields */ }
Function defines a Function that implements some processing in the flow hierarchy

Implementations

Configure a function with additional information after it is deserialized as part of a flow

Set the id of this function

Get the id of this function

Get the name of any associated docs file

Get the id of the low this function is a part of

Return true if this function is impure or not

Get a reference to the set of inputs of this function

Get a mutable reference to the set of inputs of this function

Get a reference to the set of outputs this function generates

Add a connection from this function to another

Get a reference to the set of output connections from this function to others

Get a reference to the implementation of this function

Set the implementation location of this function

Get the source url for the file where this function was defined

Get the lib reference of this function