pub struct IO { /* private fields */ }
IO contains information about the Input or Output of a Function or Flow

Implementations

Is this IO an input or an output of a Flow?

Return a reference to the IOType of this IO

Set the IO type

Return a reference to the data type this IO generates or accepts

Set the route where this IO resides in the flow hierarchy

Set the datatypes of this IO

Get a reference to the input initializer of this IO

Set the input initializer of this IO