Module flowclib::model::process_reference
source · [−]Expand description
process_reference is an object used within a flow to reference a process defined elsewhere
Structs
A ProcessReference is the struct used in a Flow to refer to a sub-process (Function or nested
Flow) it contains