pub struct ProcessReference {
    pub alias: Name,
    pub source: String,
    pub initializations: HashMap<String, InputInitializer>,
}
A ProcessReference is the struct used in a Flow to refer to a sub-process (Function or nested Flow) it contains

Fields

alias: Name

A reference may have an alias - this is used when multiple instances of the same Process are referenced from within a flow - they need difference aliases to distinguish between them in connections to/from them

source: String

Relative or absolute source of the referenced process

initializations: HashMap<String, InputInitializer>

When a process is references, each reference can set different initial values on the inputs of the referenced process.

Implementations

if the ProcessRef does not specify an alias for the process to be loaded then set the alias to be the name of the loaded process