pub enum RouteType {
    Input(NameRoute),
    Output(Name),
    Internal(NameRoute),
    Invalid(String),
}
A Route can be of various Types

Variants

Input(NameRoute)

The route refers to an input of a Process

Output(Name)

The Route refers to the output of a Process

Internal(NameRoute)

The route is internal to a Process

Invalid(String)

The route is invalid (needed for errors during deserialization)