Loader is responsible for parsing flow definitions from text files and creating in memory

Enums

LibType describes what format the Flow Library is written in

Traits

Many structs in the model implement the Validate method which is used to check the description deserialized from file obeys some additional constraints that cannot be expressed in the struct definition in serde

Functions

Load a Flow definition from a Url, recursively loading all sub-processes referenced.

load library metadata from the given url using the provider. Currently it uses the package table of Cargo.toml as a source but it could easily use another file as along as it has the required fields to satisfy MetaData struct