pub struct GenerationTables {
pub connections: Vec<Connection>,
pub sources: HashMap<Route, (Source, usize)>,
pub destination_routes: HashMap<Route, (usize, usize, usize)>,
pub collapsed_connections: Vec<Connection>,
pub functions: Vec<Function>,
pub libs: HashSet<Url>,
pub source_files: Vec<String>,
}Expand description
GenerationTables are built from the flattened and connected flow model in memory and are
used to generate the flow’s manifest ready to be executed.
Fields
connections: Vec<Connection>The set of connections between functions in the compiled flow
sources: HashMap<Route, (Source, usize)>HashMap of sources of values and what route they are connected to
destination_routes: HashMap<Route, (usize, usize, usize)>HashMap from “route of the output of a function” –> (output name, source_function_id)
collapsed_connections: Vec<Connection>HashMap from “route of the input of a function” –> (destination_function_id, input number, flow_id)
functions: Vec<Function>The set of functions left in a flow after it has been flattened, connected and optimized
libs: HashSet<Url>The set of libraries used by a a flow, from their Urls
source_files: Vec<String>The list of source files that were used in the flow definition
Implementations