Struct flowclib::model::connection::Connection
source · [−]pub struct Connection { /* private fields */ }Expand description
Connection defines a connection between the output of one function or flow to the input
of another function or flow and maybe optionally named for legibility/debugging.
Implementations
Connect the from_io to the to_io if they are compatible
Return a mutable reference to the from_io