pub trait HasDataTypes { fn datatypes(&self) -> &Vec<DataType>; }
Trait that is used on multiple objects to get their data type
Return a reference to the datatype of the object implementing this trait