pub struct Flow {
pub name: Name,
pub inputs: IOSet,
pub outputs: IOSet,
pub process_refs: Vec<ProcessReference>,
pub connections: Vec<Connection>,
pub metadata: MetaData,
pub alias: Name,
pub id: usize,
pub source_url: Url,
pub route: Route,
pub subprocesses: HashMap<Name, Process>,
pub lib_references: HashSet<Url>,
/* private fields */
}Expand description
Flow defines a parent or child flow in the nested flow hierarchy
Fields
name: Namename given to this flow
inputs: IOSetinputs that this flow defines
outputs: IOSetoutputs that this flow defines
process_refs: Vec<ProcessReference>Set of sub-processes referenced (used) in this flow
connections: Vec<Connection>connections within this flow, from flow input or to flow outputs
metadata: MetaDatametadata about flow author, versions etc
alias: NameWhen the same process is used multiple times within a single flow, to disambiguate between them each one must be given an alias that is used to refer to it
id: usizeflows are assigned a numeric id in the hierarchy
source_url: Urlsource_url is the url of the file/resource where this flow definition was read from
route: Routeroute defines the location in the hierarchy of flows where this ones resides
subprocesses: HashMap<Name, Process>subprocesses are the loaded definition of the processes reference (used) within this flow
lib_references: HashSet<Url>lib_references is the set of library references used in this flow
Implementations
Return a default value for a Url as part of a flow
Get a mutable reference to the set of inputs this flow defines
Configure a flow with additional information after it is deserialized from file
Iterate over all the connections defined in the flow, and attempt to connect the source and destination, checking the types are compatible