pub struct IO { /* private fields */ }
IO contains information about the Input or Output of a Function or Flow
Is this IO an input or an output of a Flow?
Return a reference to the IOType of this IO
Return a reference to the data type this IO generates or accepts
Set the route where this IO resides in the flow hierarchy
Set the datatypes of this IO
Get a reference to the input initializer of this IO
Set the input initializer of this IO
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
Deserialize this value from the given Serde deserializer. Read more
Formats the value using the given formatter. Read more
Return a reference to the datatype of the object implementing this trait
Return a reference to the name of the struct implementing this trait
Return a reference to the alias (also a Name type) of the struct implementing this trait
Return a reference to the Route of the struct that implements this trait
Return a mutable reference to the Route of the struct that implements this trait
Serialize this value into the given Serde serializer. Read more
Validate that a deserialized model data structure is valid for use
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
Uses borrowed data to replace owned data, usually by cloning. Read more
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.